@@ -8,7 +8,7 @@ package Object::Pad;
 use strict;
 use warnings;
 
-our $VERSION = '0.30';
+our $VERSION = '0.31';
 
 use Carp;
 
@@ -529,30 +529,6 @@ sub begin_class
    Object::Pad::_begin_class( $name, $args{extends} );
 }
 
-sub Object::Pad::MOP::Class::add_method
-{
-   my $self = shift;
-   my ( $name, $code ) = @_;
-
-   if( $name eq "BUILD" ) {
-      carp "Adding a named method called BUILD is not recommended; use ->add_BUILD directly";
-      $self->add_BUILD( $code );
-   }
-
-   $self->_add_method( $name, $code );
-}
-
-sub Object::Pad::MOP::Class::_add_method
-{
-   my $self = shift;
-   my ( $name, $code ) = @_;
-
-   my $pkg = $self->name;
-
-   no strict 'refs';
-   *{"${pkg}::${name}"} = $code;
-}
-
 # The universal base-class methods
 
 sub Object::Pad::UNIVERSAL::BUILDARGS
